# Set up testing for an application

::::{grid} 1 2 2 3
:gutter: 1 1 1 2

:::{grid-item-card} {octicon}`bug;2.5em;sd-mr-1 sd-animate-grow50` Test functionality and performance
:link: pytest
:link-type: doc

How to add unit and performance testing with Pytest.
:::

:::{grid-item-card} {octicon}`eye;2.5em;sd-mr-1 sd-animate-grow50` Test UI rendering
:link: uitests
:link-type: doc

This guide addresses how to test the rendered UI with Pytest and Playwright.
:::

:::{grid-item-card} {octicon}`people;2.5em;sd-mr-1 sd-animate-grow50` Test operating capacity
:link: loadtests
:link-type: doc

How to test performance by simulating multiple users accessing an app concurrently.
:::


::::

```{toctree}
:titlesonly:
:hidden:
:maxdepth: 1

pytest
uitests
loadtests
```
